@@ -2,7 +2,7 @@ import requests
 
 def send(unprodata, url):
 
-  req = request.post(url=url, data=unprodata)
+  req = requests.post(url=url, data=unprodata)
   response = request.urlopen(req)
 
   return response.text
\ No newline at end of file
